@@ -13,7 +13,7 @@ import logging
 import ctypes as ct
 import multiprocessing as mp 
 
-from fcmaes import cmaes, de, cmaescpp, decpp, dacpp, hhcpp, gcldecpp, lcldecpp, ldecpp, csmacpp, bitecpp
+from fcmaes import cmaes, de, cmaescpp, decpp, dacpp, gcldecpp, lcldecpp, ldecpp, csmacpp, bitecpp
 
 _logger = None
 
@@ -67,7 +67,7 @@ def dtime(t0):
 class wrapper(object):
     """Fitness function wrapper for use with parallel retry."""
 
-    def __init__(self, fit, logger = logger()):
+    def __init__(self, fit, logger):
         self.fit = fit
         self.evals = mp.RawValue(ct.c_int, 0) 
         self.best_y = mp.RawValue(ct.c_double, math.inf) 
@@ -80,7 +80,7 @@ class wrapper(object):
         y0 = y if np.isscalar(y) else sum(y)
         if y0 < self.best_y.value:
             self.best_y.value = y0
-            if not logger is None:
+            if not self.logger is None:
                 self.logger.info(str(dtime(self.t0)) + ' '  + 
                           str(self.evals.value) + ' ' + 
                           str(self.best_y.value) + ' ' + 
@@ -536,23 +536,6 @@ class Da_cpp(Optimizer):
                             rg=rg, runid = self.get_count_runs(store))
         return ret.x, ret.fun, ret.nfev
 
-class Hh_cpp(Optimizer):
-    """Harris hawks C++ implementation."""
-    
-    def __init__(self, max_evaluations=50000,
-                 popsize = 31, stop_fitness = None):        
-        Optimizer.__init__(self, max_evaluations, 'hh cpp')
-        self.popsize = popsize
-        self.stop_fitness = stop_fitness
-
-    def minimize(self, fun, bounds, guess=None, sdevs=None, rg=Generator(MT19937()), store=None):
-        ret = hhcpp.minimize(fun, len(bounds.lb), bounds, 
-                popsize=self.popsize, 
-                max_evaluations = self.max_eval_num(store), 
-                stop_fitness = self.stop_fitness,
-                rg=rg, runid = self.get_count_runs(store))
-        return ret.x, ret.fun, ret.nfev
-
 class Csma_cpp(Optimizer):
     """SCMA C++ implementation."""
    
